#ifndef _CAN_APP_H_
#define _CAN_APP_H_
#include "g_includes.h"
#include "CAN_Lib.h"
 void Can_Set_Buff_18FEC1EE(canlib_uint8_t CopyData[]);
 void Can_Set_Buff_18FEFC17(canlib_uint8_t CopyData[]);
 void Can_Set_Buff_10FF4117(canlib_uint8_t CopyData[]);
 void Can_Set_Buff_0CFE6CEE(canlib_uint8_t CopyData[]);
 void Can_Set_Buff_0810A000(canlib_uint8_t CopyData[]);
 void Can_Set_Buff_0A18A000(canlib_uint8_t CopyData[]);
 void Can_Set_Buff_18FFC321(canlib_uint8_t CopyData[]);
 void Can_Set_Buff_18FF6121(canlib_uint8_t CopyData[]);
 void Can_Set_Buff_18FEE6EE(canlib_uint8_t CopyData[]);
 void Can_Set_Buff_18D00017(canlib_uint8_t CopyData[]);
 void Can_Set_Buff_18A97121(canlib_uint8_t CopyData[]);
 //uint8_t CrcCheckSum(uint8_t *data, uint8_t len);

#endif
